/*============= Native 与 h5 交互 =============*/
/*
 * ios WebviewJavascriptBriage
 * android newslistener / imglistener
 */
var SHAREMAPPER = {
	1: "wxtimeline", //"微信朋友圈"
	2: "wxsession", //"微信好友"
	3: "weibo", //"新浪微博"
	4: "qqzone" //"QQ空间"
}

/**
 * 获取url中的参数
 * @returns {{}} 键值对的形式
 */
function getUrlParam() {
    var search = window.location.search.substr(1);
    var mappers = search.split("&");
    var hash = {};
    for(var i in mappers){
        var index = mappers[i].indexOf("=");
        hash[mappers[i].substring(0,index)] = mappers[i].substring(index+1)
    }
    return hash;
}

function setCommentCount(count){
	if(count && count != "0"){
		$(".commentCount").text(count);
		$(".comment-count").show();
	}else{
		$(".comment-count").hide();
	}
}

function resizeFontSize(size,response){
	switch(size){
		case 0 : $(".content").removeClass("fs-md").removeClass("fs-lg").addClass("fs-sm"); return;
		case 1 : $(".content").removeClass("fs-sm").removeClass("fs-lg").addClass("fs-md"); return;
		case 2 : $(".content").removeClass("fs-sm").removeClass("fs-md").addClass("fs-lg"); return;
		default: $(".content").removeClass("fs-sm").removeClass("fs-lg").addClass("fs-md"); return;
	}
}

function initLoadData(data){
	window.net = data.net || "";
	window.imageList = data.imageList || [];
}

function rebuildContent(data, images){
	try{
		return data.replace(/\${{(\d+)}}\$/g,function(match, num){
	        var image = _find(images,"key="+num);
	        var html = "<div class='img-box'><img class='news-img' src='"+image.src+"'></div>";
	        return html;
	    });
	}catch(e){
		console.error(e);
	}
    
}

function getFormatTime(time){
    var current = (new Date()).getTime();
    var cross = current - time;
    cross = Math.round(cross/1000);
    if(cross < 2){
        return "刚刚发布";
    }
    if(cross < 60){
        return cross+"秒前"
    }
    if(cross > 60 && cross < 3600){
        cross = Math.round(cross/60);
        return cross+"分钟前"
    }
    if(cross > 3600 && cross < 3600*24){
        cross = Math.floor(cross/3600);
        return cross+"小时前"
    }
    if(cross > 3600*24){
        cross = Math.floor(cross/(3600*24));
        return cross+"天前"
    }
}

function _find(arr,hash){
	var key = hash.split("=")[0];
	var val = hash.split("=")[1];
	for(var i = 0; i < arr.length; i++){
		if(arr[i][key] == val){
			return arr[i];
		}
	}
	return {};
}

function connectWebViewJavascriptBridge(callback) {
    if (window.WebViewJavascriptBridge) {
        callback(WebViewJavascriptBridge)
    } else {
        document.addEventListener('WebViewJavascriptBridgeReady', function() {
          	callback(WebViewJavascriptBridge)
        }, false)
    }
}

function vm(){
	this.title = "";
	this.origin = "";
	this.pubtime = "";
	this.content = "";
	this.setTitle = function(){
		$("#news-title").html(this.title)
	}
	this.setOrigin = function(){
		$("#news-origin").html(this.origin)
	}
	this.setPubtime = function(){
		$("#news-pubtime").html(this.pubtime)
	}
	this.setContent = function(){
		$("#news-content").html(this.content)
	}
}
vm.prototype.render = function (data) {
	this.setTitle();
	this.setOrigin();
	this.setPubtime();
	this.setContent();
}

function Page(){
	this.vm = new vm();
	this.init();
}

Page.prototype = {
	init: function(){
		this.initIOS();
		this.initData();
		this.initBorder();
		this.bindEvent();
	},
	bindEvent: function(){
		var Self = this,
			plat = Self.getUA();
		$('.share-icon-list-app li').on("click",{Self: Self},function(){
			// 调用native注册的方法 
			var type = $(this).data("type");
			if(plat == "ios"){
				WebViewJavascriptBridge.callHandler("receiveJavaScriptHandler",{
					action: 2,
					name: "tapShare",
					data: {
						platform: type,
						name: SHAREMAPPER[type]
					} 
				},function(response){
					//alert(response);
				})
			}
			if(plat == "android"){
				newslistner.share(type);
			}
			if(!plat){
				alert("您的手机暂不支持分享");
			}
		})
		$('.playBtn').on("click",function(){
			var imgBox = $(this).parents(".img-box");
			imgBox.find("img").css({'z-index':0});
			$(this).removeClass("playBtn").addClass("loading");
			var key = imgBox.data("key");
			var img = new Image();
			var that = this;
			img.src = _find(imageList,"key="+key).src;
			img.onload = function(){
				imgBox.find("img").attr("src",img.src);
				$(that).hide();
			}
		})
		$('.img-page').on("click",{Self: Self},function(){
			// 调用native注册的方法，查看一张图片
			var index = $(this).parents(".img-box").data("index") || 0;
			if(plat == "ios"){
				WebViewJavascriptBridge.callHandler("receiveJavaScriptHandler",{
					action: 1,
					name: "tapImage",
					data: {
						index: index
					}
				},function(response){
					
				})
			}else if(plat == "android"){
				imagelistner.openImage(index);
			}else{
				return;
			}
		})
		$('.bug-report').on("click",{Self: Self},function(){
			if(plat == "ios"){
				WebViewJavascriptBridge.callHandler("receiveJavaScriptHandler",{
					action: 3,
					name: "tapReport"
				},function(response){
					
				})
			}else if(plat == "android"){
				newslistner.report();
			}else{
				return;
			}
		})
		$('.browse-origin').on("click",{Self: Self},function(){
			if(plat == "ios"){
				WebViewJavascriptBridge.callHandler("receiveJavaScriptHandler",{
					action: 4,
					name: "tapOrigin"
				},function(response){
					
				})
			}else if(plat == "android"){
				newslistner.origin();
			}else{
				return;
			}
		})
		$('.content').on("click",function(e){
			var nodeName = $(e.target)[0].nodeName;
			if(nodeName && nodeName.toLowerCase() != "img"){
				if(plat == "ios"){
					WebViewJavascriptBridge.callHandler("receiveJavaScriptHandler",{
						action: 5,
						name: "tapTitleBar"
					},function(response){
						
					})
				}else if(plat == "android"){
					imagelistner.hideTopBar();
				}else{
					return;
				}	
			}
		})
		$(".comment-icon").on("click",function(){
			// android bind a click event
			if(plat == "android"){
				imagelistner.jumpToComment();
			}else{
				return;
			}
		})
		document.body.addEventListener('touchstart', function () { }); 
		$(".content a").on('click', function (e) { e.preventDefault(); }); 
	},
	getUA: function(){
		var UA = navigator.userAgent.toLowerCase(), plat = null;
		if(UA.match(/iphone|ipad|ipod/)){
			plat = "ios";
		}
		if(UA.match(/android/)){
			plat = "android";
		}
		return plat;
	},
	initIOS: function(){
	    connectWebViewJavascriptBridge(function(bridge) {
	        bridge.init();
	        bridge.registerHandler("resizeFontSize",resizeFontSize);
	        bridge.registerHandler("initLoadData",initLoadData);
	        bridge.registerHandler("setCommentCount",setCommentCount);
	    })
	},
	initBorder: function(){
		var ua = this.getUA();
		if(ua == "ios"){
			$("body").addClass("ios-device");
		}else{
			$("body").addClass("other-device");
		}
	},
	initData: function(){
		var preview = getUrlParam().preview;
		if(!preview){
			return;
		}
		var Self = this;
		var newsId = getUrlParam().newsId || '2000034cd054b505',
			parentType = 'CHANNEL',
			parentId = '31',
			newsType = "NEWS";
		$.ajax({
			type: "get",
			url: "/v1/news/detail",
			data: {
				newsId: newsId,
				newsType: newsType,
				parentType: parentType,
				parentId: parentId
			},
			success: function(data){
				if(data.code == "10000"){
					with(data.data){
						Self.vm.title = title;
						Self.vm.content = rebuildContent(content,newsImageInfoList);
						Self.vm.origin = source || "溜达咨询";
						Self.vm.pubtime = getFormatTime(publishTime);
					}
					Self.vm.render();
				}
			},
			dataType: "json"
		})	
	}
}
var page = new Page();
